package CUED::EDDA::Comments;
use base CUED::EDDA::DBIC;

use warnings;
use strict;

=head1 NAME

CUED::EDDA::Comments - what it says on the tin

=head1 VERSION

Version 0.01

=cut

our $VERSION = '0.01';

=head1 SYNOPSIS

Retrieves info about Commentss, expect methods to be used by
CUED::EDDA::Person

=head1 CONSTRUCTORS

=head2 

=cut

# method for retrieving records by personnel key, inherited by Person, Staff etc
sub view_info {
    my ($proto,$view) = @_;
    my $class = ref($proto) || $proto;
    my @view = $class->schema()->resultset('Comments')
	->search({view_name => $view});
    my %records;
    if (@view > 0) {
    
	# get the data
	foreach my $record (@view) {
	    my $id = $record->comment_id;
	    $records{$id}{'col'} = $record->column_name || "-";
	    $records{$id}{'source'} = $record->source_table || "-";
	    $records{$id}{'descr'} = $record->data_description || "-";
	    $records{$id}{'conv'} = $record->data_conventions || "-";
	    $records{$id}{'qual'} = $record->data_quality || "-";
	    $records{$id}{'usage'} = $record->usage_comments || "-";
	}
    }
    return %records;
}
    
=head1 AUTHOR

    Michael Gray, C<< <mjg17 at eng.cam.ac.uk> >>
	
=head1 SUPPORT
	
    You can find documentation for this module with the perldoc command.

    perldoc CUED::EDDA::Comments

=head1 ACKNOWLEDGEMENTS

=head1 COPYRIGHT & LICENSE

Copyright 2006 Michael Gray, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut

1; # End of CUED::EDDA::Comments
