use strict;
use warnings;

package CUED::EDDA::Config;

our $VERSION = '0.01';

use Carp;
use Config::General;

use constant CONFIG_FILE => '/etc/edda.conf';
use constant DOT_FILE    => '.edda.conf';

sub get ($) {
    my ($self, $section) = @_;
    my $file = $self->_get_file_name();
    my $conf = Config::General->new(
				    -ConfigFile     => $file,
				    -ExtendedAccess => 1,
				    );

    my %conf;
    if ($section) {
	if ($conf->exists($section)) {
	    %conf = $conf->obj($section)->getall();
	} else {
	    return undef;
	}
    } else {
	%conf = $conf->getall();
    }
    return \%conf;
}

sub _get_file_name ($$) {
    my $self = shift;
    my $file;
    $file = $self->_env_file();
    $file = $self->_dot_file() unless $file;
    $file = $self->_app_file() unless $file;
    return $file;
}

sub _env_file ($) {
    my $self = shift;
    my $file = $ENV{CUED_EDDA_CONF};
    return undef unless $file;
    if ( -r $file ) {
	carp "WARNING: using \$ENV{CUED_EDDA_CONF} config file: $file"
	    if $ENV{CUED_EDDA_CONFIG_WARNINGS};
	return $file;
    } else {
	croak "ERROR: cannot find \$ENV{CUED_EDDA_CONF} config file: $file";
    }
    return undef;
}

sub _dot_file ($) {
    my $self = shift;

    if (not defined $ENV{HOME}) {
	return undef;
    }

    my $file = $ENV{HOME} . '/' . DOT_FILE;
    if ( -r $file ) {
	carp "WARNING: using private config file: $file"
	    if $ENV{CUED_EDDA_CONFIG_WARNINGS};
	return $file;
    }

    return undef;
}

sub _app_file ($$) {
    my $self = shift;
    return CONFIG_FILE;
}

1;
