use strict;
use warnings;

package CUED::EDDA::DBIC;

use Carp;

use CUED::EDDA::Config;
use CUED::EDDA::Schema;

use constant DSN => 'dbi:Oracle:host=oracle-serv.eng.cam.ac.uk;sid=admindb';
use constant DEFAULT_USER => 'webdbase';

use constant DATE_SQL => <<"_DATE_SQL_";
alter session set NLS_DATE_FORMAT = 'YYYY-MM-DD HH24:MI:SS'
_DATE_SQL_

my $config = CUED::EDDA::Config->get('Database');

my $schema = CUED::EDDA::Schema->connect(
					 DSN,
					 get_user(),
					 get_password(),
					 {AutoCommit=>1},
					 );

$schema->storage->on_connect_do([ DATE_SQL ]);

# get the database user
sub get_user {
    if ($ENV{CUED_EDDA_USER}) {
	carp "WARNING: taking db user from \$ENV{CUED_EDDA_USER}"
	    if $ENV{CUED_EDDA_CONFIG_WARNINGS};
	return $ENV{CUED_EDDA_USER};
    }
    return $config->{user};
}

# get the password for the database user
sub get_password {
    if ($ENV{CUED_EDDA_PW}) {
	carp "WARNING: taking db password from \$ENV{CUED_EDDA_PW}"
	    if $ENV{CUED_EDDA_CONFIG_WARNINGS};
	return $ENV{CUED_EDDA_PW};
    }
    return $config->{password};
}

sub schema {
    my $self = shift;
    return $schema;
}

# method for retrieving records by personnel key, inherited by Person, Staff etc
# FIXME: may now be better per-client to avoid class->resultset translation
#
sub by_pk {
    my ($proto,$pk) = @_;
    my $class = ref($proto) || $proto;
    my ($resultset_name) = ($class =~ /::(\w+)$/);
    my $p = $schema->resultset($resultset_name)->find($pk);
    return $p;
}

sub retrieve_all {
    my $proto = shift;
    my $class = ref($proto) || $proto;
    my ($resultset_name) = ($class =~ /::(\w+)$/);
    return $schema->resultset($resultset_name)->search();
}

# Get the database handle

sub dbh {
    my $class = shift;
    return $class->schema()->storage()->dbh();
}

1;
