package CUED::EDDA::Schema::Person;

use 5.006;
use strict;
use warnings;

use base 'DBIx::Class';

our $VERSION = '0.01';

__PACKAGE__->load_components(qw(Core));

__PACKAGE__->table('edda_people');
__PACKAGE__->add_columns(qw(
				      personnel_key
				      crsid
				      engid
				      start_date
				      surname
				      forenames
				      preferred_name
				      initials
				      nationality
				      gender
				      class
				      dob
				      title
				      college_id
				      email
				      x_directory_eng
				      left
				      arrived
				      fax
				      postal
				      actual_room
				      actual_phone
				      mobile
));

__PACKAGE__->set_primary_key('personnel_key');

# Convenience:
#
sub resultset() {
    my ($self, $resultset_name) = @_;
    return $self->result_source()->schema()->resultset($resultset_name);
}

sub collaborator() {
    my $self = shift;
    my $p = $self->resultset('Collaborator')->find($self->personnel_key);
    return $p;
}

sub other() {
    my $self = shift;
    my $p = $self->resultset('Other')->find($self->personnel_key);
    return $p;
}

sub retired() {
    my $self = shift;
    my $p = $self->resultset('Retired')->find($self->personnel_key);
    return $p;
}

sub pgrad() {
    my $self = shift;
    my $p = $self->resultset('Pgrad')->find($self->personnel_key);
    return $p;
}

sub visitor() {
    my $self = shift;
    my $p = $self->resultset('Visitor')->find($self->personnel_key);
    return $p;
}

sub student() {
    my $self = shift;
    my $p = $self->resultset('Student')->find($self->personnel_key);
    return $p;
}

sub staff () {
    my $self = shift;
    my @p = $self->resultset('Staff')
	->search({personnel_key => $self->personnel_key});
    return @p;
}

sub ugrad () {
    my $self = shift;
    if (my $student = $self->student) {
	if ($student->current_course() =~ /(EGT\d|MET\d)/) {
	    return 1;
	}
    }
    return 0;
}

sub ugrad1 () {
    my $self = shift;
    my $p = $self->resultset('Ugrad1')->find_current($self->personnel_key);
    return $p;
}

sub ugrad2 () {
    my $self = shift;
    my $p = $self->resultset('Ugrad2')->find_current($self->personnel_key);
    return $p;
}

sub ugrad3 () {
    my $self = shift;
    my $p = $self->resultset('Ugrad3')->find_current($self->personnel_key);
    return $p;
}

sub ugrad4 () {
    my $self = shift;
    my $p = $self->resultset('Ugrad4')->find_current($self->personnel_key);
    return $p;
}

sub tcollaborator () {
    my $self = shift;
    if ($self->class =~ /tcollaborator/) { return 1; }
    return 0;
}

sub fullname() {
    my $person = shift;
    my $name = join(" ",($person->preferred_name 
			 || $person->forenames 
			 || $person->initials 
			 || $person->title 
			 || ""),
		    ($person->surname || "")); 
    return $name;
}

my %class_name = (
	       staff => "Staff",
	       pgrad => "Postgraduate",
	       ugrad => "Undergraduate",
	       collaborator => "Research Collaborator",
	       retired => "Emeritus Member of Dept",
	       other => "Other",
	       visitor => "Visitor",
	       tcollaborator => "Teaching Collaborator",
	       );

sub longclass() {
    my $person = shift;
    my $longclass = $class_name{$person->class} || "Unknown";
    return $longclass;
}

sub longcoll() {
    my $person = shift;
    my $longcoll;
    if (my $coll = $person->college_id) {
	my $college =  $person->resultset('College')->by_id($coll);
	$longcoll = $college->college_name;
    }
    return $longcoll;
}

1;
